# unitorch.cli.models.minigpt4

## MiniGPT4Blip2LlamaProcessor

::: unitorch.cli.models.minigpt4.MiniGPT4Blip2LlamaProcessor

## MiniGPT4Blip2LlamaForGeneration

::: unitorch.cli.models.minigpt4.MiniGPT4Blip2LlamaForGeneration
